gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [taler-exchange] 02/04: fix keyup invocation.


From: gnunet
Subject: [GNUnet-SVN] [taler-exchange] 02/04: fix keyup invocation.
Date: Wed, 03 Apr 2019 18:09:49 +0200

This is an automated email from the git hooks/post-receive script.

marcello pushed a commit to branch master
in repository exchange.

commit dc7d74caeabaaf5fdd3120c09b57585970f1520d
Author: Marcello Stanisci <address@hidden>
AuthorDate: Wed Apr 3 18:02:58 2019 +0200

    fix keyup invocation.
---
 src/lib/testing_api_cmd_exec_keyup.c | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/src/lib/testing_api_cmd_exec_keyup.c 
b/src/lib/testing_api_cmd_exec_keyup.c
index d534db06..e457a28e 100644
--- a/src/lib/testing_api_cmd_exec_keyup.c
+++ b/src/lib/testing_api_cmd_exec_keyup.c
@@ -49,7 +49,7 @@ struct KeyupState
 
   /**
    * If GNUNET_YES, then the fake @e now value will be
    * passed to taler-exchange-keyup via the --timestamp
    * option.
    */
   unsigned int with_now;
@@ -85,7 +85,7 @@ keyup_run (void *cls,
        "taler-exchange-keyup",
        "-c", ks->config_filename,
        "-o", "auditor.in",
-       "--timestamp",
+       "--time",
        GNUNET_STRINGS_absolute_time_to_string (ks->now),
        NULL);
   }
@@ -106,6 +106,9 @@ keyup_run (void *cls,
     TALER_TESTING_interpreter_fail (is);
     return;
   }
+
+  /* This function does not tell whether the command
+   * succeeded or not!  */
   TALER_TESTING_wait_for_sigchld (is);
 }
 
@@ -49,7 +49,7 @@ struct KeyupState
   /**
    * If GNUNET_YES, then the fake @e now value will be
-   * passed to taler-exchange-keyup via the --timestamp
+   * passed to taler-exchange-keyup via the --time
    * option.
    */

-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]